==> 0.8.1.tar.gz: lib/src/themes/yaru.dart <==
import 'package:yaru/src/colors.dart';
import 'package:yaru/src/themes/common_themes.dart';

const _primaryColor = YaruColors.orange;

final yaruLight = createYaruLightTheme(
  primaryColor: _primaryColor,
  elevatedButtonColor: YaruColors.success,
);

final yaruDark = createYaruDarkTheme(
  primaryColor: _primaryColor,
  elevatedButtonColor: YaruColors.success,
);

final yaruSageLight = createYaruLightTheme(
  primaryColor: YaruColors.sage,
);

final yaruSageDark = createYaruDarkTheme(
  primaryColor: YaruColors.sage,
);

final yaruPrussianGreenLight = createYaruLightTheme(
  primaryColor: YaruColors.prussianGreen,
);

final yaruPrussianGreenDark = createYaruDarkTheme(
  primaryColor: YaruColors.prussianGreen,
);

final yaruOliveLight = createYaruLightTheme(
  primaryColor: YaruColors.olive,
);

final yaruOliveDark = createYaruDarkTheme(
  primaryColor: YaruColors.olive,
);

final yaruBarkLight = createYaruLightTheme(
  primaryColor: YaruColors.bark,
);

final yaruBarkDark = createYaruDarkTheme(
  primaryColor: YaruColors.bark,
);

final yaruViridianLight = createYaruLightTheme(
  primaryColor: YaruColors.viridian,
);

final yaruViridianDark = createYaruDarkTheme(
  primaryColor: YaruColors.viridian,
);

final yaruPurpleLight = createYaruLightTheme(
  primaryColor: YaruColors.purple,
);

final yaruPurpleDark = createYaruDarkTheme(
  primaryColor: YaruColors.purple,
);

final yaruRedLight = createYaruLightTheme(
  primaryColor: YaruColors.red,
);

final yaruRedDark = createYaruDarkTheme(
  primaryColor: YaruColors.red,
);

final yaruBlueLight = createYaruLightTheme(
  primaryColor: YaruColors.blue,
);

final yaruBlueDark = createYaruDarkTheme(
  primaryColor: YaruColors.blue,
);

final yaruMagentaLight = createYaruLightTheme(
  primaryColor: YaruColors.magenta,
);

final yaruMagentaDark = createYaruDarkTheme(
  primaryColor: YaruColors.magenta,
);

==> 1.2.0.tar.gz: lib/src/themes/yaru.dart <==
import 'package:yaru/src/colors.dart';
import 'package:yaru/src/themes/common_themes.dart';

const _primaryColor = YaruColors.orange;

final yaruLight = createYaruLightTheme(
  primaryColor: _primaryColor,
  elevatedButtonColor: YaruColors.light.success,
);

final yaruDark = createYaruDarkTheme(
  primaryColor: _primaryColor,
  elevatedButtonColor: YaruColors.dark.success,
);

final yaruSageLight = createYaruLightTheme(
  primaryColor: YaruColors.sage,
);

final yaruSageDark = createYaruDarkTheme(
  primaryColor: YaruColors.sage,
);

final yaruPrussianGreenLight = createYaruLightTheme(
  primaryColor: YaruColors.prussianGreen,
);

final yaruPrussianGreenDark = createYaruDarkTheme(
  primaryColor: YaruColors.prussianGreen,
);

final yaruOliveLight = createYaruLightTheme(
  primaryColor: YaruColors.olive,
);

final yaruOliveDark = createYaruDarkTheme(
  primaryColor: YaruColors.olive,
);

final yaruBarkLight = createYaruLightTheme(
  primaryColor: YaruColors.bark,
);

final yaruBarkDark = createYaruDarkTheme(
  primaryColor: YaruColors.bark,
);

final yaruViridianLight = createYaruLightTheme(
  primaryColor: YaruColors.viridian,
);

final yaruViridianDark = createYaruDarkTheme(
  primaryColor: YaruColors.viridian,
);

final yaruPurpleLight = createYaruLightTheme(
  primaryColor: YaruColors.purple,
);

final yaruPurpleDark = createYaruDarkTheme(
  primaryColor: YaruColors.purple,
);

final yaruRedLight = createYaruLightTheme(
  primaryColor: YaruColors.red,
);

final yaruRedDark = createYaruDarkTheme(
  primaryColor: YaruColors.red,
);

final yaruBlueLight = createYaruLightTheme(
  primaryColor: YaruColors.blue,
);

final yaruBlueDark = createYaruDarkTheme(
  primaryColor: YaruColors.blue,
);

final yaruMagentaLight = createYaruLightTheme(
  primaryColor: YaruColors.magenta,
);

final yaruMagentaDark = createYaruDarkTheme(
  primaryColor: YaruColors.magenta,
);
